# Rotor database

This repo contains a list of rotor geometries and the associated experimental
data. All these data were found in articles, technical reports, theses, etc. The
reference is always listed alongside the files.

## Organization

Every entry comes with at least two csv files:

- `<rotor_name>_geom.csv` contains the geometric parameters of the rotor
- `<rotor_name>_data.csv` contains the experimental measurements

### General file info

All files start with some commented lines (_i.e._, lines starting with `#`).
These comments indicate

- the origin of the data
- "tags" to quickly identify topics of interest with `grep` or similar tools
- the units of the columns

The available tags are compiled in the following table

| Tag          | Description                                                   |
|------------- | ------------------------------------------------------------- |
| `hover`      | Hovering helicopter                                           |
| `axial`      | Helicopter in axial climb/descent                             |
| `oblique`    | Oblique flows (_e.g._, helicopter in forward flight)          |
| `coaxial`    | Coaxial rotors                                                |
| `propeller`  | Aircraft propeller                                            |
| `incomplete` | Incomplete datasets (no all data in reproduced in the csv)    |

### Geometry files

The geometry files are standardized so they all share the same formatting,
columns order, etc. They are also **all given in SI units**.

The columns represent the different parameters, while the rows give the values
of these parameters in some specific blade sections. This means that the first
data always corresponds to the section at the blade root cutout, while the last
data corresponds to the section at blade tip.

### Data files

The data files reflect the available information in the source material. It is
currently not planned to standardize them, so each file should be scrutinized
properly before usage in your codes. The data are presented in their original
units, so use it with caution.

### Scripts

Small scripts/functions will be provided in the future in the `scripts/`
directory to help you load and parse the data in the most common languages.

## Contributing

Any contribution to this database is more than welcomed. A small python script
will be provided shortly to streamline the generation of the geometry file.

## List of rotors

- NACA-TN-626: Knight & Hefner, Static Thrust Analysis of the Lifting Airscrew
- NASA-TM-81232: Caradonna & Tung, Experimental and Analytical Studies of a
  Model Helicopter Rotor in Hover
